@@ -173,10 +173,39 @@ return meal_ptr;
 
 void modify_meal(char *meal_date, int meal, int num, char *qty)
 {
-struct meal *m, *meal_ptr = &meal_root;
-int count = 0;
-float newqty;
-while (meal_ptr->next != NULL)
+struct meal *m = NULL, *meal_ptr = &meal_root;
+int count = 0, nut = -1;
+float newqty, total = 0, thiscontrib = 0;
+if (qty != NULL && strcmp(qty,"protein") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"prot") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"pro") == 0) nut = PROCNT;
+else if (qty != NULL && strcmp(qty,"carb") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"car") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"fat") == 0) nut = FAT;
+if (nut != -1) while (meal_ptr->next != NULL)
+ {
+ if (strcmp(meal_date,meal_ptr->next->meal_date) == 0 && meal == meal_ptr->next->meal) 
+  {
+  count++;
+  if (count == num) m = meal_ptr;
+  total += options.mealsperday * meal_ptr->next->grams / 100 * FoodIndex[meal_ptr->next->food_no]->nutrient[nut];
+  }
+ meal_ptr = meal_ptr->next;
+ }
+if (nut != -1 && m != NULL)
+ {
+ thiscontrib = options.mealsperday * m->next->grams / 100 * FoodIndex[m->next->food_no]->nutrient[nut];
+ newqty = (thiscontrib + DV[nut] - total) / thiscontrib * m->next->grams;
+ if (newqty <= 0)
+  {
+  meal_ptr = m->next;
+  m->next = m->next->next;
+  free(meal_ptr);
+  }
+ else if (FoodIndex[m->next->food_no]->nutrient[nut] > 0) m->next->grams = newqty;
+ return;
+ }
+if (nut == -1) while (meal_ptr->next != NULL)
  {
  if (strcmp(meal_date,meal_ptr->next->meal_date) == 0 && meal == meal_ptr->next->meal) 
   {
@@ -198,6 +227,122 @@ while (meal_ptr->next != NULL)
  }
 }
 
+void pcf(char *meal_date, int meal, char *substring)
+{
+struct meal *start_ptr = &meal_root, *end_ptr, *p_ptr = NULL, *c_ptr = NULL, *f_ptr;
+char buffer[128];
+char *token;
+int p, c, f, count = 0, i, j;
+float contributors[3], pcfmatrix[3][4], whereweare;
+
+for (i = 0; i < 3; i++)
+ {
+ contributors[i] = 0;
+ for (j = 0; j < 3; j++) pcfmatrix[i][j] = 0;
+ }
+
+strncpy(buffer,substring,127);
+token = strtok(buffer," ");
+
+token = (strtok(NULL," "));
+if (token != NULL) p = atoi(token);
+else p = 0;
+
+token = (strtok(NULL," "));
+if (token != NULL) c = atoi(token);
+else c = 0;
+
+token = (strtok(NULL," "));
+if (token != NULL) f = atoi(token);
+else f = 0;
+
+if (p < 1 || c < 1 || f < 1) return;
+if (p == c || p == f || c == f) return;
+
+while (start_ptr != NULL)
+ {
+ if ((strcmp(start_ptr->next->meal_date,meal_date) == 0) && start_ptr->next->meal == meal) break;
+ start_ptr = start_ptr->next;
+ }
+
+if (start_ptr == NULL) return;
+
+end_ptr = start_ptr;
+p_ptr = NULL;
+c_ptr = NULL;
+f_ptr = NULL;
+
+while (end_ptr != NULL)
+ {
+ count++;
+ if (end_ptr->next == NULL) break;
+ if ((strcmp(end_ptr->next->meal_date,meal_date) != 0) || end_ptr->next->meal != meal) break;
+ if (p == count)
+  {
+  p_ptr = end_ptr->next;
+  pcfmatrix[0][0] = FoodIndex[p_ptr->food_no]->nutrient[PROCNT] / 100 / DV[PROCNT] * options.mealsperday;
+  pcfmatrix[0][1] = FoodIndex[p_ptr->food_no]->nutrient[CHO_NONFIB] / 100 / DV[CHO_NONFIB] * options.mealsperday;
+  pcfmatrix[0][2] = FoodIndex[p_ptr->food_no]->nutrient[FAT] / 100 / DV[FAT] * options.mealsperday;
+  pcfmatrix[0][3] = p_ptr->grams;
+  }
+ else if (c == count)
+  {
+  c_ptr = end_ptr->next;
+  pcfmatrix[1][0] = FoodIndex[c_ptr->food_no]->nutrient[PROCNT] / 100 / DV[PROCNT] * options.mealsperday;
+  pcfmatrix[1][1] = FoodIndex[c_ptr->food_no]->nutrient[CHO_NONFIB] / 100 / DV[CHO_NONFIB] * options.mealsperday;
+  pcfmatrix[1][2] = FoodIndex[c_ptr->food_no]->nutrient[FAT] / 100 / DV[FAT] * options.mealsperday;
+  pcfmatrix[1][3] = c_ptr->grams;
+  }
+ else if (f == count)
+  {
+  f_ptr = end_ptr->next;
+  pcfmatrix[2][0] = FoodIndex[f_ptr->food_no]->nutrient[PROCNT] / 100 / DV[PROCNT] * options.mealsperday;
+  pcfmatrix[2][1] = FoodIndex[f_ptr->food_no]->nutrient[CHO_NONFIB] / 100 / DV[CHO_NONFIB] * options.mealsperday;
+  pcfmatrix[2][2] = FoodIndex[f_ptr->food_no]->nutrient[FAT] / 100 / DV[FAT] * options.mealsperday;
+  pcfmatrix[2][3] = f_ptr->grams;
+  }
+ else
+  {
+  contributors[0] += FoodIndex[end_ptr->next->food_no]->nutrient[PROCNT] * end_ptr->next->grams / 100 / DV[PROCNT] * options.mealsperday;
+  contributors[1] += FoodIndex[end_ptr->next->food_no]->nutrient[CHO_NONFIB] * end_ptr->next->grams / 100 / DV[CHO_NONFIB] * options.mealsperday;
+  contributors[2] += FoodIndex[end_ptr->next->food_no]->nutrient[FAT] * end_ptr->next->grams / 100 / DV[FAT] * options.mealsperday;
+  }
+ end_ptr = end_ptr->next;
+ }
+
+if (end_ptr == NULL) return;
+if (p_ptr == NULL) return;
+if (c_ptr == NULL) return;
+if (f_ptr == NULL) return;
+
+
+if (! (pcfmatrix[0][3] == pcfmatrix[0][3])) pcfmatrix[0][3] = 0;
+else if (pcfmatrix[0][3] > 100000) pcfmatrix[0][3] = 0;
+else if (pcfmatrix[0][3] < -100000) pcfmatrix[0][3] = 0;
+if (! (pcfmatrix[1][3] == pcfmatrix[1][3])) pcfmatrix[1][3] = 0;
+else if (pcfmatrix[1][3] > 100000) pcfmatrix[1][3] = 0;
+else if (pcfmatrix[1][3] < -100000) pcfmatrix[1][3] = 0;
+if (! (pcfmatrix[2][3] == pcfmatrix[2][3])) pcfmatrix[2][3] = 0;
+else if (pcfmatrix[2][3] > 100000) pcfmatrix[2][3] = 0;
+else if (pcfmatrix[2][3] < -100000) pcfmatrix[2][3] = 0;
+
+for (i = 0; i < 400; i++)
+ {
+ whereweare = contributors[0] + (pcfmatrix[0][3] * pcfmatrix[0][0]) + (pcfmatrix[1][3] * pcfmatrix[1][0]) + (pcfmatrix[2][3] * pcfmatrix[2][0]);
+ pcfmatrix[0][3] -= (whereweare - 1) / pcfmatrix[0][0];
+
+ whereweare = contributors[1] + (pcfmatrix[0][3] * pcfmatrix[0][1]) + (pcfmatrix[1][3] * pcfmatrix[1][1]) + (pcfmatrix[2][3] * pcfmatrix[2][1]);
+ pcfmatrix[1][3] -= (whereweare - 1) / pcfmatrix[1][1];
+
+ whereweare = contributors[2] + (pcfmatrix[0][3] * pcfmatrix[0][2]) + (pcfmatrix[1][3] * pcfmatrix[1][2]) + (pcfmatrix[2][3] * pcfmatrix[2][2]);
+ pcfmatrix[2][3] -= (whereweare - 1) / pcfmatrix[2][2];
+ }
+
+p_ptr->grams = pcfmatrix[0][3];
+c_ptr->grams = pcfmatrix[1][3];
+f_ptr->grams = pcfmatrix[2][3];
+}
+
 void delete_meal_with_ptr(struct meal *target)
 {
 struct meal *meal_ptr = &meal_root;
@@ -230,10 +375,39 @@ while (meal_ptr->next != NULL)
 
 void modify_theusual(char *meal_date, int num, char *qty)
 {
-struct meal *m, *theusual_ptr = &theusual_root;
-int count = 0;
-float newqty;
-while (theusual_ptr->next != NULL)
+struct meal *m = NULL, *theusual_ptr = &theusual_root;
+int count = 0, nut = -1;
+float newqty, total = 0, thiscontrib = 0;
+if (qty != NULL && strcmp(qty,"protein") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"prot") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"pro") == 0) nut = PROCNT;
+else if (qty != NULL && strcmp(qty,"carb") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"car") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"fat") == 0) nut = FAT;
+if (nut != -1) while (theusual_ptr->next != NULL)
+ {
+ if (strcmp(meal_date,theusual_ptr->next->meal_date) == 0) 
+  {
+  count++;
+  if (count == num) m = theusual_ptr;
+  total += options.mealsperday * theusual_ptr->next->grams / 100 * FoodIndex[theusual_ptr->next->food_no]->nutrient[nut];
+  }
+ theusual_ptr = theusual_ptr->next;
+ }
+if (nut != -1 && m != NULL)
+ {
+ thiscontrib = options.mealsperday * m->next->grams / 100 * FoodIndex[m->next->food_no]->nutrient[nut];
+ newqty = (thiscontrib + DV[nut] - total) / thiscontrib * m->next->grams;
+ if (newqty <= 0)
+  {
+  theusual_ptr = m->next;
+  m->next = m->next->next;
+  free(theusual_ptr);
+  }
+ else if (FoodIndex[m->next->food_no]->nutrient[nut] > 0) m->next->grams = newqty;
+ return;
+ }
+if (nut == -1) while (theusual_ptr->next != NULL)
  {
  if (strcmp(meal_date,theusual_ptr->next->meal_date) == 0) 
   {
