@@ -314,13 +314,13 @@ void carb_absolute()
 {
 char buf[128];
 header("NUT:  Carbohydrate Absolute Amount");
-spacer(0);
-printf("\nEnter grams of carbohydrate (just <enter> for default):  ");
+spacer(1);
+printf("\nEnter grams of carbohydrate, or a negative value to set grams of non-fiber carb");
+printf("\nindependent of fiber (just <enter> for default):  ");
 get_string(buf,127);
 options.abnuts[CHOCDF] = atof(buf);
 options.locknuts[CHOCDF] = 0;
-if ( options.abnuts[CHOCDF] <= 0 ) options.abnuts[CHOCDF] = 0;
-if ( options.abnuts[CHOCDF] > 0 )
+if ( options.abnuts[CHOCDF] != 0 )
  {
  options.pccarb = 0;
  options.locknuts[CHOCDF] = 1;
@@ -431,6 +431,7 @@ if (options.pcprotein > 0) DV[PROCNT] = options.pcprotein / 100 * DV[ENERC_KCAL]
 if (options.abnuts[PROCNT] > 0) DV[PROCNT] = options.abnuts[PROCNT];
 if (options.pccarb > 0) DV[CHOCDF] = options.pccarb / 100 * DV[ENERC_KCAL] / options.carbcalpergm;
 if (options.abnuts[CHOCDF] > 0) DV[CHOCDF] = options.abnuts[CHOCDF];
+if (options.abnuts[CHOCDF] < 0) DV[CHOCDF] = DV[FIBTG] + -1 * options.abnuts[CHOCDF];
 if (DV[PROCNT] != DVBase[PROCNT] || DV[CHOCDF] != DVBase[CHOCDF])
  {
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
@@ -470,8 +471,8 @@ if (options.pcsatfat > 0)
  DV[FASAT] = DVBase[FASAT] * buf * options.pcsatfat * .1;
  DV[FAMS] = temp - DV[FASAT];
  }
-if (options.abnuts[CHOCDF] > 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAT] > 0) DV[FAT] = options.abnuts[FAT];
-if (options.abnuts[CHOCDF] > 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAMS] > 0) DV[FAMS] = options.abnuts[FAMS];
+if (options.abnuts[CHOCDF] != 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAT] > 0) DV[FAT] = options.abnuts[FAT];
+if (options.abnuts[CHOCDF] != 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAMS] > 0) DV[FAMS] = options.abnuts[FAMS];
 if (options.abnuts[CHOLE] > 0) DV[CHOLE] = options.abnuts[CHOLE]; 
 if (options.abnuts[VITA_IU] > 0) DV[VITA_IU] = options.abnuts[VITA_IU]; 
 if (options.abnuts[THIA] > 0) DV[THIA] = options.abnuts[THIA]; 
@@ -497,7 +498,7 @@ if (options.abnuts[NA] > 0) DV[NA] = options.abnuts[NA];
 if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN]; 
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
-if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
+if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] != 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
 else options.custom = 0;
 write_OPTIONS();
 }
@@ -607,7 +608,8 @@ if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
 else epadhalimit = options.epadhamax;
 
 options.abnuts[ALA] = food_work.nutrient[ALA];
-if (options.abnuts[ALA] <= 0) options.abnuts[ALA] = .00001;
+if (options.abnuts[ALA] < DV[ALA]) options.abnuts[ALA] = DV[ALA];
+extra_ala = options.abnuts[ALA] - food_work.nutrient[ALA];
 
 if ( (DefaultTarget == 90 && options.n6hufa == 0) || options.n6hufa == 90 || options.n6hufa == 15)
  {
@@ -617,10 +619,8 @@ if ( (DefaultTarget == 90 && options.n6hufa == 0) || options.n6hufa == 90 || opt
  if (options.abnuts[LA] <= 0) options.abnuts[LA] = .00001;
  options.abnuts[AA] = food_work.nutrient[AA];
  if (options.abnuts[AA] <= 0) options.abnuts[AA] = .00001;
- options.abnuts[OMEGA3] = food_work.nutrient[OMEGA3];
+ options.abnuts[OMEGA3] = food_work.nutrient[OMEGA3] + extra_ala;
  if (options.abnuts[OMEGA3] <= 0) options.abnuts[OMEGA3] = .00001;
- options.abnuts[ALA] = food_work.nutrient[ALA];
- if (options.abnuts[ALA] <= 0) options.abnuts[ALA] = .00001;
  options.abnuts[EPA] = food_work.nutrient[EPA];
  if (options.abnuts[EPA] <= 0) options.abnuts[EPA] = .00001;
  options.abnuts[DHA] = food_work.nutrient[DHA];
@@ -725,3 +725,61 @@ else
   }
  }
 }
+
+void weight_log()
+{
+char newentry[128];
+int n, nfat;
+float weightslope, fatslope;
+float weight, bf, stardate;
+time_t t;
+
+while (1)
+ {
+ header("NUT:  Weight Log Regression");
+ read_WLOG(&n,&nfat,&weightslope,&fatslope);
+ printf("\n\n");
+ printf("                           data points:   %6d\n",n);
+ printf("\n\n");
+ printf("  Based on the trend\n");
+ printf("  of data points so far...\n\n\n");
+ if (n < 2) printf("         Predicted daily weight change:        ?\n\n");
+ else printf("         Predicted daily weight change:   %+10.3f\n\n",weightslope);
+ if (nfat < 2)
+  {
+  printf("      Predicted daily lean mass change:        ?\n\n");
+  printf("       Predicted daily fat mass change:        ?\n\n");
+  }
+ else
+  {
+  printf("      Predicted daily lean mass change:   %+10.3f\n\n",weightslope-fatslope);
+  printf("       Predicted daily fat mass change:   %+10.3f\n\n",fatslope);
+  }
+ spacer(14);
+ if (n > 0) printf("Type daily weight and body fat %% (! to clear log, <enter> to quit):  ");
+ else printf("Type daily weight and body fat %% (<enter> to quit):  ");
+ get_string(newentry,127);
+ if (strlen(newentry) == 0 || newentry[0] == ' ') return;
+ if (strchr(newentry,'!') != NULL)
+  {
+  weight = 0;
+  if (n > 0) write_WLOG(&weight,&bf,&stardate);
+  }
+ else
+  {
+  time(&t);
+  if (strchr(newentry,' ') == NULL || newentry[strlen(newentry)-1] == ' ')
+   {
+   weight   = atof(strtok(newentry," "));
+   bf = 0;
+   }
+  else
+   {
+   weight   = atof(strtok(newentry," "));
+   bf       = atof(strtok(NULL," "));
+   }
+  stardate = ((float) t / 86400) - 14486;
+  if (weight > 0) write_WLOG(&weight,&bf,&stardate);
+  }
+ }
+}
